#!/usr/bin/ruby
require "narray"
require "num/numcomplex"
require "num/numarray"
require "benchmark"
include Benchmark
include NMath

na = NArray.complex(200,200,200).indgen!
nu = NumArray.span(NumComplex,200,200,200)

print "complex, (200, 200, 200)\n\n"
print "### NArray vs. NumArray ###\n\n"

print "\n+++ shisoku +++\n\n"
bmbm do |x|
  x.report("NArray") {
      na*na
      na-na
      na/na
      na+na
  }
  x.report("NumArray") {
      nu*nu
      nu-nu
      nu/nu
      nu+nu
  }
end

print "\n\n+++ shisoku (with scalar) +++\n\n"
bmbm do |x|
  x.report("NArray") {
    na*1.0
    na-1.0
    na/1.0
    na+1.0
  }
  x.report("NumArray") {
    nu*1.0
    nu-1.0
    nu/1.0
    nu+1.0
  }
end

print "\n\n+++ shisoku (with scalar, coerced) +++\n\n"
bmbm do |x|
  x.report("NArray") {
    1.0*na
    1.0-na
    1.0/na
    1.0+na
  }
  x.report("NumArray") {
    1.0*nu
    1.0-nu
    1.0/nu
    1.0+nu
  }
end

=begin
print "\n\n+++ math +++\n\n"
bmbm do |x|
  x.report("NArray") {
    sin(na)
    cos(na)
    tan(na)
  }
  x.report("NumArray") {
    nu.sin
    nu.cos
    nu.tan
  }
end
=end

print "\n\n+++ sum, av +++\n\n"
bmbm do |x|
  x.report("NArray") {
    na.sum
    na.mean
    #(na.stddev)*(na.stddev)
    #na.stddev
  }
  x.report("NumArray") {
    nu.sum
    nu.av
    #nu.var
    #nu.rms
  }
end

=begin
print "\n\n+++ max, min +++\n\n"
bmbm do |x|
  x.report("NArray") {
    na.max
    na.min
    #na.median
  }
  x.report("NumArray") {
    nu.max
    nu.min
    #nu.median
  }
end
=end

print "\n\n+++ transpose +++\n\n"
bmbm do |x|
  x.report("NArray") { 
    na.transpose(2,1,0)
  }
  x.report("NumArray") {
    nu.transpose
  }
end

print "\n"
